#!/usr/bin/env bash
# Author: fotios lindiakos (fotios@csh.rit.edu)
# Modified by ben-agaric (http://agaric.com/contact)
# Usage note: Run from the root of your Drupal installation.
# Usage: new_site.sh [project_name_in_lower_case] [liquid|fixed] ["Theme Name"] ["Theme Description"]


# Argument handling
PROJECT=${1:-new_project}
LAYOUT=$(echo ${2:-liquid} | tr "[:upper:]" "[:lower:]")
NAME=${3:-$(whoami)}
DESC=${4:-"No Description Available"}

# Some widely used vars
ZB=sites/all/themes/zen
TH=sites/default/themes
DIR_STARTERKIT=STARTERKIT
ZEN_FOLDER=zen
INFO_FILE="$PROJECT.info"

############# Error Checking #############
# Make sure the STARTERKIT exists
# Make sure the destination does not exist
# (1) Make sure the project name is valid [a-z_]
# Make sure they chose either liquid of fixed
if [ ! -d "$ZB/$DIR_STARTERKIT" ]; then
ERROR="'$DIR_STARTERKIT' does not exist!!";
elif [ -d "$TH/$PROJECT" ]; then
ERROR="'$PROJECT' already exists!!";
elif [ $(echo "$PROJECT" | grep '[^a-z_]') ]; then
ERROR="Invalid project name, must be only lower case or _";
elif [ ! $(echo "$LAYOUT" | grep -e liquid -e fixed) ]; then
ERROR="Layout must be either liquid or fixed";
fi;

# Exit if there are errors
if [ ! -z "$ERROR" ]; then
printf "Error: %s\nExiting..." "$ERROR";
exit 1;
fi

#############       Work     #############
# (0) Create default themes directory if does not exist.
if [ ! -d "$TH" ]; then
  mkdir $TH;
fi;

# (1) Copy the whole directory
cp -pr $ZB/$DIR_STARTERKIT $TH/$PROJECT

# (3,4,5) Copy the required CSS files
cp -p $ZB/$ZEN_FOLDER/layout-$LAYOUT.css $TH/$PROJECT/layout.css
cp -p $ZB/$ZEN_FOLDER/print.css $TH/$PROJECT/
touch $TH/$PROJECT/$PROJECT.css

# Change to the new directory
cd $TH/$PROJECT

# (2) Rename the .info file
mv STARTERKIT.info $INFO_FILE

# (2) Change the name and description in the .info file
sed 's/\(name.*= \)Zen.*$/\1'"$NAME"'/' $INFO_FILE > temp &&
mv temp $INFO_FILE
sed 's/\(description.*= \)Read the.*$/\1'"$DESC"'/' $INFO_FILE > temp &&
mv temp $INFO_FILE

# (2,6) Change all references of STARTERKIT to your project name
for file in `echo "$INFO_FILE template.php theme-settings.php"`
do
 echo .
  sed 's/STARTERKIT/'$PROJECT'/g' $file > temp
  mv temp $file
done
